@@ -78,6 +78,36 @@ class Payload(object):
             return self.old
         return self.new
 
+    def foreign_key_constraint(self, model) -> dict:
+        """
+        {
+            'public.customer': {  referred table with a fully qualified name
+                'local': 'customer_id',
+                'remote': 'id',
+                'value': 1
+            },
+            'public.group': {  referred table with a fully qualified name
+                'local': 'group_id',
+                'remote': 'id',
+                'value': 1
+            }
+        }
+        """
+        constraints: dict = {}
+        for foreign_key in model.foreign_keys:
+            referred_table: str = str(foreign_key.constraint.referred_table)
+            constraints.setdefault(referred_table, {})
+            if foreign_key.constraint.column_keys:
+                if foreign_key.constraint.column_keys[0] in self.data:
+                    constraints[referred_table] = {
+                        "local": foreign_key.constraint.column_keys[0],
+                        "remote": foreign_key.column.name,
+                        "value": self.data[
+                            foreign_key.constraint.column_keys[0]
+                        ],
+                    }
+        return constraints
+
 
 class TupleIdentifierType(sa.types.UserDefinedType):
     cache_ok: bool = True
@@ -453,7 +483,7 @@ class Base(object):
         upto_nchanges: Optional[int] = None,
         limit: Optional[int] = None,
         offset: Optional[int] = None,
-    ) -> List[sa.engine.row.LegacyRow]:
+    ) -> List[sa.engine.row.Row]:
         """Peek a logical replication slot without consuming changes.
 
         SELECT * FROM PG_LOGICAL_SLOT_PEEK_CHANGES('testdb', NULL, 1)
