@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """Sync module."""
 import asyncio
 import json
@@ -32,7 +30,6 @@ from .constants import (
     TRUNCATE,
     UPDATE,
 )
-from .elastichelper import ElasticHelper
 from .exc import (
     ForeignKeyError,
     InvalidSchemaError,
@@ -45,6 +42,7 @@ from .node import Node, Tree
 from .plugin import Plugins
 from .querybuilder import QueryBuilder
 from .redisqueue import RedisQueue
+from .search_client import SearchClient
 from .singleton import Singleton
 from .transform import Transform
 from .utils import (
@@ -84,7 +82,7 @@ class Sync(Base, metaclass=Singleton):
         super().__init__(
             document.get("database", self.index), verbose=verbose, **kwargs
         )
-        self.es: ElasticHelper = ElasticHelper()
+        self.search_client: SearchClient = SearchClient()
         self.__name: str = re.sub(
             "[^0-9a-zA-Z_]+", "", f"{self.database.lower()}_{self.index}"
         )
@@ -247,8 +245,8 @@ class Sync(Base, metaclass=Singleton):
                 sys.stdout.flush()
 
     def create_setting(self) -> None:
-        """Create Elasticsearch setting and mapping if required."""
-        self.es._create_setting(
+        """Create Elasticsearch/OpenSearch setting and mapping if required."""
+        self.search_client._create_setting(
             self.index,
             self.tree,
             setting=self.setting,
@@ -332,7 +330,9 @@ class Sync(Base, metaclass=Singleton):
         self.drop_replication_slot(self.__name)
 
     def get_doc_id(self, primary_keys: List[str], table: str) -> str:
-        """Get the Elasticsearch document id from the primary keys."""
+        """
+        Get the Elasticsearch/OpenSearch document id from the primary keys.
+        """  # noqa D200
         if not primary_keys:
             raise PrimaryKeyNotFoundError(
                 f"No primary key found on table: {table}"
@@ -430,10 +430,14 @@ class Sync(Base, metaclass=Singleton):
                         payload.tg_op != payload2.tg_op
                         or payload.table != payload2.table
                     ):
-                        self.es.bulk(self.index, self._payloads(payloads))
+                        self.search_client.bulk(
+                            self.index, self._payloads(payloads)
+                        )
                         payloads: list = []
                 elif j == len(rows):
-                    self.es.bulk(self.index, self._payloads(payloads))
+                    self.search_client.bulk(
+                        self.index, self._payloads(payloads)
+                    )
                     payloads: list = []
             self.logical_slot_get_changes(
                 self.__name,
@@ -447,6 +451,84 @@ class Sync(Base, metaclass=Singleton):
             total += len(changes)
             self.count["xlog"] += len(rows)
 
+    def _root_primary_key_resolver(
+        self, node: Node, payload: Payload, filters: list
+    ) -> list:
+        fields: dict = defaultdict(list)
+        primary_values: list = [
+            payload.data[key] for key in node.model.primary_keys
+        ]
+        primary_fields: dict = dict(
+            zip(node.model.primary_keys, primary_values)
+        )
+        for key, value in primary_fields.items():
+            fields[key].append(value)
+        for doc_id in self.search_client._search(
+            self.index, node.table, fields
+        ):
+            where: dict = {}
+            params: dict = doc_id.split(PRIMARY_KEY_DELIMITER)
+            for i, key in enumerate(self.tree.root.model.primary_keys):
+                where[key] = params[i]
+            filters.append(where)
+
+        return filters
+
+    def _root_foreign_key_resolver(
+        self, node: Node, payload: Payload, foreign_keys: dict, filters: list
+    ) -> list:
+        """
+        Foreign key resolver logic:
+
+        This resolver handles n-tiers relationships (n > 3) where we
+        insert/update a new leaf node.
+        For the node's parent, get the primary keys values from the
+        incoming payload.
+        Lookup this value in the meta section of Elasticsearch/OpenSearch
+        Then get the root node returned and re-sync that root record.
+        Essentially, we want to lookup the root node affected by
+        our insert/update operation and sync the tree branch for that root.
+        """
+        fields: dict = defaultdict(list)
+        foreign_values: list = [
+            payload.new.get(key) for key in foreign_keys[node.name]
+        ]
+        for key in [key.name for key in node.primary_keys]:
+            for value in foreign_values:
+                if value:
+                    fields[key].append(value)
+        # TODO: we should combine this with the filter above
+        # so we only hit Elasticsearch/OpenSearch once
+        for doc_id in self.search_client._search(
+            self.index,
+            node.parent.table,
+            fields,
+        ):
+            where: dict = {}
+            params: dict = doc_id.split(PRIMARY_KEY_DELIMITER)
+            for i, key in enumerate(self.tree.root.model.primary_keys):
+                where[key] = params[i]
+            filters.append(where)
+
+        return filters
+
+    def _through_node_resolver(
+        self, node: Node, payload: Payload, filters: list
+    ) -> list:
+        """Handle where node is a through table with a direct references to
+        root
+        """
+        foreign_key_constraint = payload.foreign_key_constraint(node.model)
+        if self.tree.root.name in foreign_key_constraint:
+            filters.append(
+                {
+                    foreign_key_constraint[self.tree.root.name][
+                        "remote"
+                    ]: foreign_key_constraint[self.tree.root.name]["value"]
+                }
+            )
+        return filters
+
     def _insert_op(
         self, node: Node, filters: dict, payloads: List[Payload]
     ) -> dict:
@@ -475,22 +557,38 @@ class Sync(Base, metaclass=Singleton):
                     )
                     raise
 
-                # set the parent as the new entity that has changed
-                foreign_keys = self.query_builder._get_foreign_keys(
-                    node.parent,
-                    node,
-                )
+                try:
+                    foreign_keys = self.query_builder.get_foreign_keys(
+                        node.parent,
+                        node,
+                    )
+                except ForeignKeyError:
+                    foreign_keys = self.query_builder._get_foreign_keys(
+                        node.parent,
+                        node,
+                    )
 
+                _filters: list = []
                 for payload in payloads:
-                    for i, key in enumerate(foreign_keys[node.name]):
-                        if key == foreign_keys[node.parent.name][i]:
-                            filters[node.parent.table].append(
-                                {
-                                    foreign_keys[node.parent.name][
-                                        i
-                                    ]: payload.data[key]
-                                }
-                            )
+                    for node_key in foreign_keys[node.name]:
+                        for parent_key in foreign_keys[node.parent.name]:
+                            if node_key == parent_key:
+                                filters[node.parent.table].append(
+                                    {parent_key: payload.data[node_key]}
+                                )
+
+                    _filters = self._root_foreign_key_resolver(
+                        node, payload, foreign_keys, _filters
+                    )
+
+                    # through table with a direct references to root
+                    if not _filters:
+                        _filters = self._through_node_resolver(
+                            node, payload, _filters
+                        )
+
+                if _filters:
+                    filters[self.tree.root.table].extend(_filters)
 
         else:
 
@@ -520,10 +618,10 @@ class Sync(Base, metaclass=Singleton):
 
             # Here, we are performing two operations:
             # 1) Build a filter to sync the updated record(s)
-            # 2) Delete the old record(s) in Elasticsearch if the
+            # 2) Delete the old record(s) in Elasticsearch/OpenSearch if the
             #    primary key has changed
-            #   2.1) This is crucial otherwise we can have the old
-            #        and new document in Elasticsearch at the same time
+            #   2.1) This is crucial otherwise we can have the old and new
+            #        document in Elasticsearch/OpenSearch at the same time
             docs: list = []
             for payload in payloads:
                 primary_values: list = [
@@ -559,41 +657,26 @@ class Sync(Base, metaclass=Singleton):
                     }
                     if self.routing:
                         doc["_routing"] = old_values[self.routing]
-                    if self.es.major_version < 7 and not self.es.is_opensearch:
+                    if (
+                        self.search_client.major_version < 7
+                        and not self.search_client.is_opensearch
+                    ):
                         doc["_type"] = "_doc"
                     docs.append(doc)
 
             if docs:
-                self.es.bulk(self.index, docs)
+                self.search_client.bulk(self.index, docs)
 
         else:
 
             # update the child tables
             for payload in payloads:
                 _filters: list = []
-                fields: dict = defaultdict(list)
-
-                primary_values: list = [
-                    payload.data[key] for key in node.model.primary_keys
-                ]
-                primary_fields: dict = dict(
-                    zip(node.model.primary_keys, primary_values)
+                _filters = self._root_primary_key_resolver(
+                    node, payload, _filters
                 )
-
-                for key, value in primary_fields.items():
-                    fields[key].append(value)
-
-                for doc_id in self.es._search(self.index, node.table, fields):
-                    where = {}
-                    params = doc_id.split(PRIMARY_KEY_DELIMITER)
-                    for i, key in enumerate(self.tree.root.model.primary_keys):
-                        where[key] = params[i]
-                    _filters.append(where)
-
                 # also handle foreign_keys
                 if node.parent:
-                    fields = defaultdict(list)
-
                     try:
                         foreign_keys = self.query_builder.get_foreign_keys(
                             node.parent,
@@ -605,28 +688,9 @@ class Sync(Base, metaclass=Singleton):
                             node,
                         )
 
-                    foreign_values = [
-                        payload.new.get(k) for k in foreign_keys[node.name]
-                    ]
-
-                    for key in [key.name for key in node.primary_keys]:
-                        for value in foreign_values:
-                            if value:
-                                fields[key].append(value)
-                    # TODO: we should combine this with the filter above
-                    # so we only hit Elasticsearch once
-                    for doc_id in self.es._search(
-                        self.index,
-                        node.parent.table,
-                        fields,
-                    ):
-                        where: dict = {}
-                        params = doc_id.split(PRIMARY_KEY_DELIMITER)
-                        for i, key in enumerate(
-                            self.tree.root.model.primary_keys
-                        ):
-                            where[key] = params[i]
-                        _filters.append(where)
+                    _filters = self._root_foreign_key_resolver(
+                        node, payload, foreign_keys, _filters
+                    )
 
                 if _filters:
                     filters[self.tree.root.table].extend(_filters)
@@ -637,7 +701,8 @@ class Sync(Base, metaclass=Singleton):
         self, node: Node, filters: dict, payloads: List[dict]
     ) -> dict:
 
-        # when deleting a root node, just delete the doc in Elasticsearch
+        # when deleting a root node, just delete the doc in
+        # Elasticsearch/OpenSearch
         if node.is_root:
 
             docs: list = []
@@ -655,7 +720,10 @@ class Sync(Base, metaclass=Singleton):
                 }
                 if self.routing:
                     doc["_routing"] = payload.data[self.routing]
-                if self.es.major_version < 7 and not self.es.is_opensearch:
+                if (
+                    self.search_client.major_version < 7
+                    and not self.search_client.is_opensearch
+                ):
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
@@ -665,7 +733,7 @@ class Sync(Base, metaclass=Singleton):
                 raise_on_error: Optional[bool] = (
                     False if settings.USE_ASYNC else None
                 )
-                self.es.bulk(
+                self.search_client.bulk(
                     self.index,
                     docs,
                     raise_on_exception=raise_on_exception,
@@ -678,26 +746,10 @@ class Sync(Base, metaclass=Singleton):
             # the child keys match in private, then get the root doc_id and
             # re-sync the child tables
             for payload in payloads:
-                primary_values: list = [
-                    payload.data[key] for key in node.model.primary_keys
-                ]
-                primary_fields = dict(
-                    zip(node.model.primary_keys, primary_values)
-                )
-                fields = defaultdict(list)
-
                 _filters: list = []
-                for key, value in primary_fields.items():
-                    fields[key].append(value)
-
-                for doc_id in self.es._search(self.index, node.table, fields):
-                    where = {}
-                    params = doc_id.split(PRIMARY_KEY_DELIMITER)
-                    for i, key in enumerate(self.tree.root.model.primary_keys):
-                        where[key] = params[i]
-
-                    _filters.append(where)
-
+                _filters = self._root_primary_key_resolver(
+                    node, payload, _filters
+                )
                 if _filters:
                     filters[self.tree.root.table].extend(_filters)
 
@@ -708,22 +760,25 @@ class Sync(Base, metaclass=Singleton):
         if node.is_root:
 
             docs: list = []
-            for doc_id in self.es._search(self.index, node.table):
+            for doc_id in self.search_client._search(self.index, node.table):
                 doc: dict = {
                     "_id": doc_id,
                     "_index": self.index,
                     "_op_type": "delete",
                 }
-                if self.es.major_version < 7 and not self.es.is_opensearch:
+                if (
+                    self.search_client.major_version < 7
+                    and not self.search_client.is_opensearch
+                ):
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
-                self.es.bulk(self.index, docs)
+                self.search_client.bulk(self.index, docs)
 
         else:
 
             _filters: list = []
-            for doc_id in self.es._search(self.index, node.table):
+            for doc_id in self.search_client._search(self.index, node.table):
                 where: dict = {}
                 params = doc_id.split(PRIMARY_KEY_DELIMITER)
                 for i, key in enumerate(self.tree.root.model.primary_keys):
@@ -836,7 +891,7 @@ class Sync(Base, metaclass=Singleton):
             """
             Filters are applied when an insert, update or delete operation
             occurs. For a large table update, this normally results
-            in a large sql query with multiple OR clauses
+            in a large SQL query with multiple OR clauses.
 
             Filters is a dict of tables where each key is a list of id's
             {
@@ -946,7 +1001,10 @@ class Sync(Base, metaclass=Singleton):
                 if self.routing:
                     doc["_routing"] = row[self.routing]
 
-                if self.es.major_version < 7 and not self.es.is_opensearch:
+                if (
+                    self.search_client.major_version < 7
+                    and not self.search_client.is_opensearch
+                ):
                     doc["_type"] = "_doc"
 
                 if self._plugins:
@@ -1104,7 +1162,7 @@ class Sync(Base, metaclass=Singleton):
 
         This is triggered by poll_redis.
         It is called when an event is received from Redis.
-        Deserialize the payload from Redis and sync to Elasticsearch.
+        Deserialize the payload from Redis and sync to Elasticsearch/OpenSearch
         """
         # this is used for the views.
         # we substitute the views for the base table here
@@ -1126,7 +1184,7 @@ class Sync(Base, metaclass=Singleton):
                 _payloads[payload.table].append(payload)
 
             for _payload in _payloads.values():
-                self.es.bulk(self.index, self._payloads(_payload))
+                self.search_client.bulk(self.index, self._payloads(_payload))
 
         else:
 
@@ -1140,10 +1198,14 @@ class Sync(Base, metaclass=Singleton):
                         payload.tg_op != payload2.tg_op
                         or payload.table != payload2.table
                     ):
-                        self.es.bulk(self.index, self._payloads(_payloads))
+                        self.search_client.bulk(
+                            self.index, self._payloads(_payloads)
+                        )
                         _payloads = []
                 elif j == len(payloads):
-                    self.es.bulk(self.index, self._payloads(_payloads))
+                    self.search_client.bulk(
+                        self.index, self._payloads(_payloads)
+                    )
                     _payloads: list = []
 
         txids: Set = set(map(lambda x: x.xmin, payloads))
@@ -1157,7 +1219,9 @@ class Sync(Base, metaclass=Singleton):
         txmax: int = self.txid_current
         logger.debug(f"pull txmin: {txmin} - txmax: {txmax}")
         # forward pass sync
-        self.es.bulk(self.index, self.sync(txmin=txmin, txmax=txmax))
+        self.search_client.bulk(
+            self.index, self.sync(txmin=txmin, txmax=txmax)
+        )
         # now sync up to txmax to capture everything we may have missed
         self.logical_slot_changes(txmin=txmin, txmax=txmax, upto_nchanges=None)
         self.checkpoint: int = txmax or self.txid_current
@@ -1202,7 +1266,8 @@ class Sync(Base, metaclass=Singleton):
             f"Db: [{self.count['db']:,}] => "
             f"Redis: [total = {self.count['redis']:,} "
             f"pending = {self.redis.qsize:,}] => "
-            f"Elastic: [{self.es.doc_count:,}] ...\n"
+            f"{self.search_client.name}: [{self.search_client.doc_count:,}]"
+            f"...\n"
         )
         sys.stdout.flush()
 
@@ -1239,7 +1304,7 @@ class Sync(Base, metaclass=Singleton):
             # sync up to current transaction_id
             self.pull()
             # start a background worker consumer thread to
-            # poll Redis and populate Elasticsearch
+            # poll Redis and populate Elasticsearch/OpenSearch
             self.poll_redis()
             # start a background worker thread to cleanup the replication slot
             self.truncate_slots()
