@@ -90,6 +90,7 @@ class TestBase(object):
         tables = [
             "continent",
             "country",
+            "group",
             "publisher",
             "book",
             "city",
@@ -101,6 +102,7 @@ class TestBase(object):
             "shelf",
             "author",
             "book_author",
+            "book_group",
             "rating",
             "contact",
             "contact_item",
@@ -193,6 +195,7 @@ class TestBase(object):
                 "author",
                 "book",
                 "book_author",
+                "book_group",
                 "book_language",
                 "book_shelf",
                 "book_subject",
@@ -201,6 +204,7 @@ class TestBase(object):
                 "contact_item",
                 "continent",
                 "country",
+                "group",
                 "language",
                 "publisher",
                 "rating",
