@@ -81,14 +81,14 @@ class TestParentSingleChildFkOnParent(object):
         )
 
         try:
-            sync.es.teardown(index="testdb")
+            sync.search_client.teardown(index="testdb")
         except Exception:
             raise
 
         sync.redis.delete()
         session.connection().engine.connect().close()
         session.connection().engine.dispose()
-        sync.es.close()
+        sync.search_client.close()
 
     def test_relationship_object_one_to_one(self, sync, data):
         nodes = {
@@ -489,7 +489,7 @@ class TestParentSingleChildFkOnParent(object):
                 }
             ],
         }
-        sync.es.close()
+        sync.search_client.close()
         sync.tree.__post_init__()
         with pytest.raises(RelationshipTypeError) as excinfo:
             Tree(sync.models).build(nodes)
@@ -508,7 +508,7 @@ class TestParentSingleChildFkOnParent(object):
                 }
             ],
         }
-        sync.es.close()
+        sync.search_client.close()
         sync.tree.__post_init__()
         with pytest.raises(RelationshipVariantError) as excinfo:
             Tree(sync.models).build(nodes)
@@ -526,7 +526,7 @@ class TestParentSingleChildFkOnParent(object):
                 }
             ],
         }
-        sync.es.close()
+        sync.search_client.close()
         sync.tree.__post_init__()
         with pytest.raises(RelationshipAttributeError) as excinfo:
             Tree(sync.models).build(nodes)
@@ -614,10 +614,10 @@ class TestParentSingleChildFkOnParent(object):
             },
         }
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -657,10 +657,10 @@ class TestParentSingleChildFkOnParent(object):
             session.rollback()
             raise
 
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -683,7 +683,7 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
 
     # TODO: Add another test like this and change
     # both primary key and non pkey column
@@ -710,10 +710,10 @@ class TestParentSingleChildFkOnParent(object):
             },
         }
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -775,9 +775,9 @@ class TestParentSingleChildFkOnParent(object):
                             side_effect=noop,
                         ):
                             sync.receive(NTHREADS_POLLDB)
-                            sync.es.refresh("testdb")
+                            sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -800,7 +800,7 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
 
     def test_insert_non_concurrent(self, data, book_cls, publisher_cls):
         """Test sync insert and then sync in non-concurrent mode."""
@@ -823,12 +823,12 @@ class TestParentSingleChildFkOnParent(object):
             },
         }
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
         session = sync.session
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
         assert docs == [
             {
                 "_meta": {"publisher": {"id": [1]}},
@@ -866,10 +866,10 @@ class TestParentSingleChildFkOnParent(object):
             session.rollback()
             raise
 
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -898,7 +898,7 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
 
     def test_update_non_primary_key_non_concurrent(
         self, data, book_cls, publisher_cls
@@ -923,10 +923,10 @@ class TestParentSingleChildFkOnParent(object):
             },
         }
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -962,10 +962,10 @@ class TestParentSingleChildFkOnParent(object):
             session.rollback()
             raise
 
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -988,7 +988,7 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
 
     def test_update_non_primary_key_concurrent(
         self, data, book_cls, publisher_cls
@@ -1013,10 +1013,10 @@ class TestParentSingleChildFkOnParent(object):
             },
         }
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -1070,9 +1070,9 @@ class TestParentSingleChildFkOnParent(object):
                             side_effect=noop,
                         ):
                             sync.receive(NTHREADS_POLLDB)
-                            sync.es.refresh("testdb")
+                            sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -1095,7 +1095,7 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
 
     def test_delete_concurrent(self, data, book_cls, publisher_cls):
         """Test sync delete and then sync in concurrent mode."""
@@ -1119,10 +1119,10 @@ class TestParentSingleChildFkOnParent(object):
         }
 
         sync = Sync(document)
-        sync.es.bulk(sync.index, sync.sync())
-        sync.es.refresh("testdb")
+        sync.search_client.bulk(sync.index, sync.sync())
+        sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -1189,9 +1189,9 @@ class TestParentSingleChildFkOnParent(object):
                             side_effect=noop,
                         ):
                             sync.receive(NTHREADS_POLLDB)
-                            sync.es.refresh("testdb")
+                            sync.search_client.refresh("testdb")
 
-        docs = search(sync.es, "testdb")
+        docs = search(sync.search_client, "testdb")
 
         assert docs == [
             {
@@ -1214,4 +1214,4 @@ class TestParentSingleChildFkOnParent(object):
             },
         ]
         assert_resync_empty(sync, document.get("node", {}))
-        sync.es.close()
+        sync.search_client.close()
