@@ -9,7 +9,7 @@ from mock import call, patch
 
 from pgsync.base import Base
 from pgsync.exc import SchemaError
-from pgsync.urls import get_elasticsearch_url, get_postgres_url, get_redis_url
+from pgsync.urls import get_postgres_url, get_redis_url, get_search_url
 from pgsync.utils import (
     compiled_query,
     config_loader,
@@ -70,8 +70,8 @@ class TestUtils(object):
             call("Path: ./"),
             call("\x1b[4mPostgres\x1b[0m:"),
             call("URL: {get_postgres_url}"),
-            call("\x1b[4mElasticsearch\x1b[0m:"),
-            call(f"URL: {get_elasticsearch_url()}"),
+            call("\x1b[4mSearch\x1b[0m:"),
+            call(f"URL: {get_search_url()}"),
             call("\x1b[4mRedis\x1b[0m:"),
             call(f"URL: {get_redis_url}"),
         ]
